Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(15)

Unified Diff: tests/lib/async/catch_errors13_test.dart

Issue 26151002: Rename runAsync to scheduleMicrotask. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Add test. Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/html/events_test.dart ('k') | tests/lib/async/catch_errors24_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/lib/async/catch_errors13_test.dart
diff --git a/tests/lib/async/catch_errors13_test.dart b/tests/lib/async/catch_errors13_test.dart
index 284dee91d98387ce0490e156fafe9c7fada44c94..0889f2e19340878fa3facd825b97276f41e74842 100644
--- a/tests/lib/async/catch_errors13_test.dart
+++ b/tests/lib/async/catch_errors13_test.dart
@@ -12,13 +12,13 @@ main() {
Completer done = new Completer();
var events = [];
- // Work around bug that makes runAsync use Timers. By invoking `runAsync` here
- // we make sure that asynchronous non-timer events are executed before any
- // Timer events.
- runAsync(() { });
+ // Work around bug that makes scheduleMicrotask use Timers. By invoking
+ // `scheduleMicrotask` here we make sure that asynchronous non-timer events
+ // are executed before any Timer events.
+ scheduleMicrotask(() { });
- // Test that errors are caught by nested `catchErrors`. Also uses `runAsync`
- // in the body of a Timer.
+ // Test that errors are caught by nested `catchErrors`. Also uses
+ // `scheduleMicrotask` in the body of a Timer.
catchErrors(() {
events.add("catch error entry");
catchErrors(() {
@@ -26,12 +26,12 @@ main() {
Timer.run(() { throw "timer error"; });
new Timer(const Duration(milliseconds: 50),
() {
- runAsync(() { throw "runAsync"; });
+ scheduleMicrotask(() { throw "scheduleMicrotask"; });
throw "delayed error";
});
}).listen((x) {
events.add(x);
- if (x == "runAsync") {
+ if (x == "scheduleMicrotask") {
throw "inner done throw";
}
});
@@ -56,7 +56,7 @@ main() {
"timer error",
"timer outer",
"delayed error",
- "runAsync",
+ "scheduleMicrotask",
"inner done throw"
],
events);
« no previous file with comments | « tests/html/events_test.dart ('k') | tests/lib/async/catch_errors24_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698